@@ -45,7 +45,6 @@
 #endif //ZENLIB_USEWX
 #include "ZenLib/File.h"
 #include "ZenLib/OS_Utils.h"
-#include <map>
 //---------------------------------------------------------------------------
 
 namespace ZenLib
@@ -257,9 +256,9 @@ bool File::Open (const tstring &File_Name_, access_t Access)
             switch (Access)
             {
                 case Access_Read         : dwDesiredAccess=FILE_READ_DATA; dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_EXISTING;   break;
-                case Access_Write        : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=0;                                 dwCreationDisposition=OPEN_ALWAYS;   break;
-                case Access_Read_Write   : dwDesiredAccess=FILE_READ_DATA|GENERIC_WRITE;   dwShareMode=0; dwCreationDisposition=OPEN_ALWAYS;                    break;
-                case Access_Write_Append : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_ALWAYS;   break;
+                case Access_Write        : dwDesiredAccess=GENERIC_WRITE;   dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_ALWAYS;   break;
+                case Access_Read_Write   : dwDesiredAccess=FILE_READ_DATA|GENERIC_WRITE;   dwShareMode=FILE_SHARE_READ|FILE_SHARE_WRITE; dwCreationDisposition=OPEN_ALWAYS;                    break;
+                case Access_Write_Append : dwDesiredAccess = FILE_APPEND_DATA; dwShareMode = FILE_SHARE_READ | FILE_SHARE_WRITE; dwCreationDisposition = OPEN_ALWAYS; break;
                 default                  : dwDesiredAccess=0;               dwShareMode=0;                                 dwCreationDisposition=0;             break;
             }
 
@@ -306,9 +305,10 @@ bool File::Open (const tstring &File_Name_, access_t Access)
             ZENLIB_DEBUG2(      "File Open",
                                 Debug+=", returns 1";)
 
-            //Append
             if (Access==Access_Write_Append)
-                GoTo(0, FromEnd);
+                Size_Get();
+            else
+                Position=0;
 
             return true;
         #endif
@@ -360,12 +360,12 @@ bool File::Create (const Ztring &File_Name_, bool OverWrite)
                 default                  : mode=0                            ; break;
             }*/
             ios_base::openmode access;
-            switch (OverWrite)
-            {
-                case false        : if (Exists(File_Name))
-                                        return false;
-                default           : access=ios_base::binary|ios_base::in|ios_base::out|ios_base::trunc; break;
-            }
+
+            if (!OverWrite && Exists(File_Name))
+                return false;
+
+            access=ios_base::binary|ios_base::in|ios_base::out|ios_base::trunc;
+
             #ifdef UNICODE
                 File_Handle=new fstream(File_Name.To_Local().c_str(), access);
             #else
@@ -374,11 +374,14 @@ bool File::Create (const Ztring &File_Name_, bool OverWrite)
             return ((fstream*)File_Handle)->is_open();
         #elif defined WINDOWS
             DWORD dwDesiredAccess, dwShareMode, dwCreationDisposition;
-            switch (OverWrite)
-            {
-                case false        : dwDesiredAccess=GENERIC_WRITE; dwShareMode=0;                dwCreationDisposition=CREATE_NEW;    break;
-                default           : dwDesiredAccess=GENERIC_WRITE; dwShareMode=0;                dwCreationDisposition=CREATE_ALWAYS; break;
+            if (OverWrite) {
+                dwDesiredAccess=GENERIC_WRITE;
+                dwCreationDisposition=CREATE_ALWAYS;
+            } else {
+                dwDesiredAccess=GENERIC_WRITE;
+                dwCreationDisposition=CREATE_NEW;
             }
+            dwShareMode=0;
 
             #ifdef UNICODE
                 File_Handle=CreateFileW(File_Name.c_str(), dwDesiredAccess, dwShareMode, NULL, dwCreationDisposition, 0, NULL);
@@ -789,6 +792,26 @@ Ztring File::Created_Get()
     #endif //ZENLIB_USEWX
 }
 
+//---------------------------------------------------------------------------
+#if defined WINDOWS
+static Ztring Calc_Time(const FILETIME& TimeFT)
+{
+    int64u Time64 = 0x100000000ULL * TimeFT.dwHighDateTime + TimeFT.dwLowDateTime;
+    TIME_ZONE_INFORMATION Info;
+    DWORD Result = GetTimeZoneInformation(&Info);
+    if (Result != TIME_ZONE_ID_INVALID)
+    {
+        Time64 -= ((int64s)Info.Bias) * 60 * 1000 * 1000 * 10;
+        if (Result == TIME_ZONE_ID_DAYLIGHT)
+            Time64 -= ((int64s)Info.DaylightBias) * 60 * 1000 * 1000 * 10;
+        else
+            Time64 -= ((int64s)Info.StandardBias) * 60 * 1000 * 1000 * 10;
+    }
+    Ztring Time; Time.Date_From_Milliseconds_1601(Time64 / 10000);
+    Time.FindAndReplace(__T("UTC "), __T(""));
+    return Time;
+}
+#endif
 //---------------------------------------------------------------------------
 Ztring File::Created_Local_Get()
 {
@@ -812,20 +835,7 @@ Ztring File::Created_Local_Get()
             FILETIME TimeFT;
             if (GetFileTime(File_Handle, &TimeFT, NULL, NULL))
             {
-                int64u Time64=0x100000000ULL*TimeFT.dwHighDateTime+TimeFT.dwLowDateTime;
-                TIME_ZONE_INFORMATION Info;
-                DWORD Result=GetTimeZoneInformation(&Info);
-                if (Result!=TIME_ZONE_ID_INVALID)
-                {
-                    Time64-=((int64s)Info.Bias)*60*1000*1000*10;
-                    if (Result==TIME_ZONE_ID_DAYLIGHT)
-                        Time64-=((int64s)Info.DaylightBias)*60*1000*1000*10;
-                    else
-                        Time64-=((int64s)Info.StandardBias)*60*1000*1000*10;
-                }
-                Ztring Time; Time.Date_From_Milliseconds_1601(Time64/10000);
-                Time.FindAndReplace(__T("UTC "), __T(""));
-                return Time;
+                return Calc_Time(TimeFT);
             }
             else
                 return __T(""); //There was a problem
@@ -899,20 +909,7 @@ Ztring File::Modified_Local_Get()
             FILETIME TimeFT;
             if (GetFileTime(File_Handle, NULL, NULL, &TimeFT))
             {
-                int64u Time64=0x100000000ULL*TimeFT.dwHighDateTime+TimeFT.dwLowDateTime; //100-ns
-                TIME_ZONE_INFORMATION Info;
-                DWORD Result=GetTimeZoneInformation(&Info);
-                if (Result!=TIME_ZONE_ID_INVALID)
-                {
-                    Time64-=((int64s)Info.Bias)*60*1000*1000*10;
-                    if (Result==TIME_ZONE_ID_DAYLIGHT)
-                        Time64-=((int64s)Info.DaylightBias)*60*1000*1000*10;
-                    else
-                        Time64-=((int64s)Info.StandardBias)*60*1000*1000*10;
-                }
-                Ztring Time; Time.Date_From_Milliseconds_1601(Time64/10000);
-                Time.FindAndReplace(__T("UTC "), __T(""));
-                return Time;
+                return Calc_Time(TimeFT);
             }
             else
                 return __T(""); //There was a problem
@@ -971,8 +968,10 @@ bool File::Exists(const Ztring &File_Name)
         return FN.FileExists();
     #else //ZENLIB_USEWX
         #ifdef ZENLIB_STANDARD
-            if (File_Name.find(__T('*'))!=std::string::npos || File_Name.find(__T('?'))!=std::string::npos)
-                return false;
+            #if defined WINDOWS
+                if (File_Name.find(__T('*'))!=std::string::npos || (File_Name.find(__T("\\\\?\\"))!=0 && File_Name.find(__T('?'))!=std::string::npos) || (File_Name.find(__T("\\\\?\\"))==0 && File_Name.find(__T('?'), 4)!=std::string::npos))
+                    return false;
+            #endif //defined WINDOWS
             struct stat buffer;
             int         status;
             #ifdef UNICODE
