@@ -157,7 +157,11 @@ Ztring EmptyZtring;
 //---------------------------------------------------------------------------
 #if defined(STREAM_MISSING)
     #if defined (_UNICODE)
-        #define _tnprintf snwprintf
+        #if defined (MACOS) || defined (MACOSX)
+            #define _tnprintf swprintf
+        #else
+            #define _tnprintf snwprintf
+        #endif
     #else
         #define _tnprintf snprintf
     #endif
@@ -1557,6 +1561,12 @@ std::string Ztring::To_UTF8 () const
 
         while (*Z)
         {
+            if (*Z < 0x80)
+            {
+                ToReturn += (char)(*(Z++));
+                continue;
+            }
+            
             int32u wc; // must be unsigned.
 
             #if defined(_MSC_VER)
@@ -1816,7 +1826,7 @@ int8s Ztring::To_int8s (int8u Radix, ztring_t Options) const
     #endif
 
     //Rounded
-    if (Options==Ztring_Rounded && find(__T("."))!=Error)
+    if (Options==Ztring_Rounded && find(__T('.'))!=Error)
     {
         float80 F=To_float80();
         F-=I;
@@ -1854,7 +1864,7 @@ int8u Ztring::To_int8u (int8u Radix, ztring_t Options) const
     #endif
 
     //Rounded
-    if (Options==Ztring_Rounded && find(__T("."))!=std::string::npos)
+    if (Options==Ztring_Rounded && find(__T('.'))!=std::string::npos)
     {
         float32 F=To_float32();
         F-=I;
@@ -1892,7 +1902,7 @@ int16s Ztring::To_int16s (int8u Radix, ztring_t Options) const
     #endif
 
     //Rounded
-    if (Options==Ztring_Rounded && find(__T("."))!=Error)
+    if (Options==Ztring_Rounded && find(__T('.'))!=Error)
     {
         float80 F=To_float80();
         F-=I;
@@ -1930,7 +1940,7 @@ int16u Ztring::To_int16u (int8u Radix, ztring_t Options) const
     #endif
 
     //Rounded
-    if (Options==Ztring_Rounded && find(__T("."))!=std::string::npos)
+    if (Options==Ztring_Rounded && find(__T('.'))!=std::string::npos)
     {
         float32 F=To_float32();
         F-=I;
@@ -1968,7 +1978,7 @@ int32s Ztring::To_int32s (int8u Radix, ztring_t Options) const
     #endif
 
     //Rounded
-    if (Options==Ztring_Rounded && find(__T("."))!=Error)
+    if (Options==Ztring_Rounded && find(__T('.'))!=Error)
     {
         float80 F=To_float80();
         F-=I;
@@ -2006,7 +2016,7 @@ int32u Ztring::To_int32u (int8u Radix, ztring_t Options) const
     #endif
 
     //Rounded
-    if (Options==Ztring_Rounded && find(__T("."))!=std::string::npos)
+    if (Options==Ztring_Rounded && find(__T('.'))!=std::string::npos)
     {
         float32 F=To_float32();
         F-=I;
@@ -2044,7 +2054,7 @@ int64s Ztring::To_int64s (int8u Radix, ztring_t Options) const
     #endif
 
     //Rounded
-    if (Options==Ztring_Rounded && find(__T("."))!=std::string::npos)
+    if (Options==Ztring_Rounded && find(__T('.'))!=std::string::npos)
     {
         float32 F=To_float32();
         F-=I;
@@ -2082,7 +2092,7 @@ int64u Ztring::To_int64u (int8u Radix, ztring_t Options) const
     #endif
 
     //Rounded
-    if (Options==Ztring_Rounded && find(__T("."))!=std::string::npos)
+    if (Options==Ztring_Rounded && find(__T('.'))!=std::string::npos)
     {
         float32 F=To_float32();
         F-=I;
