@@ -28,7 +28,11 @@
 #include <exception>
 #include <cstdlib>
 #include <cstdio>
-#include <new>
+#ifdef __cplusplus
+    #include <new> //for size_t
+#else /* __cplusplus */
+    #include <stddef.h> //for size_t
+#endif /* __cplusplus */
 #include "ZenLib/Conf.h"
 
 namespace ZenLib
@@ -51,7 +55,7 @@ class int128 {
 
     public:
         // Constructors
-        inline int128 () throw () {};
+        inline int128 () throw () : lo(0), hi(0) {};
         inline int128 (const int128 & a) throw () : lo (a.lo), hi (a.hi) {};
 
         inline int128 (const unsigned int & a) throw () : lo (a), hi (0ll) {};
